/**
 - XPath.sql,v 1.1 2003/07/17 14:10:45 myui Exp
 */

CREATE or REPLACE FUNCTION xpath2sql(varchar) RETURNS varchar
  AS '/usr/local/lib/xpsql/XPath.so'
  LANGUAGE 'C' IMMUTABLE STRICT;

CREATE or REPLACE FUNCTION xpath2sql(varchar,integer) RETURNS varchar
  AS '/usr/local/lib/xpsql/XPath.so'
  LANGUAGE 'C' IMMUTABLE STRICT;

CREATE TYPE __retxpatheval AS (docid integer, id integer);

CREATE or REPLACE FUNCTION xpath_eval(varchar) RETURNS setof __retxpatheval
  AS '/usr/local/lib/xpsql/XPath.so'
  LANGUAGE 'C' STRICT;

CREATE or REPLACE FUNCTION xpath_eval(varchar,integer) RETURNS setof __retxpatheval
  AS '/usr/local/lib/xpsql/XPath.so'
  LANGUAGE 'C' STRICT;

CREATE or REPLACE FUNCTION vchar2int(VARCHAR) RETURNS INTEGER
  AS '/usr/local/lib/xpsql/XPath.so'
  LANGUAGE 'C' IMMUTABLE STRICT;

CREATE or REPLACE FUNCTION vchar2real(VARCHAR) RETURNS REAL
  AS '/usr/local/lib/xpsql/XPath.so'
  LANGUAGE 'C' IMMUTABLE STRICT;

CREATE TYPE __retxpathexec AS (docid integer, result varchar);

CREATE or REPLACE FUNCTION xpath_evalx(varchar) RETURNS setof __retxpathexec
  AS '/usr/local/lib/xpsql/XPath.so'
  LANGUAGE 'C' STRICT;


/*
	-- Examples

select xpath2sql('/aaa/bbb[2][aaa="bbb"]');
select * from xpath_eval('/aaa/bbb[2][aaa="bbb"]');

*/
